@@ -26,32 +26,32 @@ class HostList : public std::map<guint32, Host *>
 {
     public:
 
-        //! Returns the singleton instance.
-	static HostList* getInstance();
-
-        //! Explicitly deletes the singleton instance.
-        static void deleteInstance();
-        
-	void remove(Host *item);
-
-        void add(Host *ch);
-
-    protected:
 	//! Default constructor.
 	HostList();
 
 	//! Destructor.
         ~HostList();
+        
+	void remove(Host *item);
+
+        void add(Host *ch);
+
+        Host *get_next_host();
+
+        void set_active_host(Host *host) {active_host = host;};
+
+        Host *get_active_host() const {return active_host;};
+
+        //! Clears all elements.
+        void lClear();
 
     private:
 
         //! Erases an Item from the list and frees the element too.
         void lErase(iterator it);
 
-        //! Clears all elements.
-        void lClear();
 
-        static HostList* d_instance;
+        Host *active_host;
 };
 
 #endif //HOSTLIST_H
