@@ -20,32 +20,52 @@
 
 #include <gtkmm.h>
 #include "event-date-region.h"
+#include "host-list.h"
+class HostedEventList;
+
+class Host;
+class Event;
+class HostList;
 
 class Listerola
 {
     public:
 
-        //! Returns the singleton instance.
-	static Listerola* getInstance();
-
-        //! Explicitly deletes the singleton instance.
-        static void deleteInstance();
-        
-        EventDateRegion get_current_date() const {return current_event_time;};
-        void set_current_date(EventDateRegion now) {current_event_time = now;};
-
-    protected:
 	//! Default constructor.
-	Listerola();
+	Listerola(std::string listings_file, double column_hours, double hour_interval);
 
 	//! Destructor.
         ~Listerola();
 
-    private:
+        EventDateRegion get_current_date() const {return current_event_time;};
+        void set_current_date(EventDateRegion now) {current_event_time = now;};
 
+        HostedEventList get_events(Host *host = NULL);
+
+        double overlap_end(Event *event);
+        double overlap_start(Event *event);
+
+        double get_duration() {return get_current_date().get_duration();};
+
+        double get_interval() {return hour_interval;};
+
+        void next();
+    
+        void random_fill(int num_channels);
+
+        HostList& get_host_list() {return channels;};
+
+    private:
+        HostList channels;
+
+        //! The data file that holds the channel listings.
+        std::string listings_file;
+
+        //! The window of time that we're interested in.
         EventDateRegion current_event_time;
 
-        static Listerola* d_instance;
+        //! The length of each slice of our window in time.
+        double hour_interval;
 };
 
-#endif //HOSTLIST_H
+#endif //LISTEROLA_H
